@@ -3,13 +3,13 @@ import math as m
 import sys
 import os
 
-#only necessary while the module is not installed in pckgs
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-
 import numpy as np
 from scipy import integrate
 from scipy.special import beta
 
+#only necessary while the module is not installed in pckgs
+sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
+
 from applied_stats import continuous_distributions as stats
 from applied_stats import mle
 
@@ -140,22 +140,27 @@ class Test_MLE(unittest.TestCase):
 
 # discrete distributions
 
-    def test_bernoulli(self):
-        a = mle.bernoulli(X_discrete)
-        self.assertEqual(a, 52.22) #
-
     def test_binomial(self):
-        b = mle.binomial(X_discrete)
-        self.assertEqual(b, 52.22)
+        b = mle.binomial(100, X_discrete)
+        self.assertEqual(round(b,4), 0.5222) #p-hat
 
     def test_geometric(self):
         c = round(mle.geometric(X_discrete),5)
-        self.assertEqual(c, 0.01915)
+        self.assertEqual(c, 0.01915)#p-hat
 
     def test_poisson(self):
         d = mle.poisson(X_discrete)
-        self.assertEqual(d, 52.22)
+        self.assertEqual(d, 52.22)#lambda-hat
 
+class Test_Hypotheses(unittest.TestCase):
+    
+    def test_gen_test(self):
+        pass
+    
+class Test_conf_intervals(unittest.TestCase):
+    
+    def test_norm_ci(self):
+        pass
 
 if __name__ == '__main__':
     unittest.main()
